@@ -1,9 +1,9 @@
 """A zero-overhead library for PyTorch users."""
-__version__ = '0.0.3'
+__version__ = '0.0.4'
 
 from . import data  # noqa
 from . import hardware  # noqa
 from . import random  # noqa
+from ._stream import Stream  # noqa
+from ._utils import ProgressTracker, Timer, evaluation, improve_reproducibility  # noqa
 from .data import collate, concat, iter_batches  # noqa
-from .stream import Stream  # noqa
-from .utils import ProgressTracker, Timer, evaluation  # noqa
